<?php

namespace Drupal\cloudflare_stream\Service;

use Drupal\Core\Entity\EntityInterface;

/**
 * Defines an interface for the CloudflareStream API service.
 */
interface CloudflareStreamApiInterface {

  /**
   * Upload a video using a single HTTP request.
   *
   * @param \Drupal\Core\Entity\EntityInterface $file
   *   The video file.
   *
   * @return \Psr\Http\Message\ResponseInterface
   *   The response from the Cloudflare Stream.
   */
  public function uploadVideoByHttpRequest(EntityInterface $file);

  /**
   * Get the embed code HTML for a video on Cloudflare Stream.
   *
   * @param string $identifier
   *   The identifier of the video.
   *
   * @return \Psr\Http\Message\ResponseInterface
   *   The response from the Cloudflare Stream.
   */
  public function getEmbedCodeHtml(string $identifier);

  /**
   * Delete a video on Cloudflare Stream.
   *
   * @param string $identifier
   *   The identifier of the video.
   *
   * @return \Psr\Http\Message\ResponseInterface
   *   The response from the Cloudflare Stream.
   */
  public function deleteVideo(string $identifier);

  /**
   * List up to 1000 videos in one request.
   *
   * @param string|null $after
   *   Show videos created after this date-time.
   * @param string|null $before
   *   Show videos created before this time.
   * @param bool $include_counts
   *   Include stats in the response about the number of videos in response
   *   range and total number of videos available.
   * @param string|null $search
   *   A string provided in this field will be used to search over the 'name'
   *   key in meta field, which can be set with the upload request of after.
   * @param int|null $limit
   *   Number of videos to include in the response.
   * @param bool $asc
   *   List videos in ascending order of creation.
   * @param string|null $status
   *   Filter by statuses.
   *
   * @return \Psr\Http\Message\ResponseInterface
   *   The response from the Cloudflare Stream.
   */
  public function listVideos(string $after = NULL, string $before = NULL, bool $include_counts = FALSE, string $search = NULL, int $limit = NULL, bool $asc = FALSE, string $status = NULL);

}
